@@ -27,6 +27,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
 #include "image-loader.h"
+#include "file-data.h"
 
 G_BEGIN_DECLS
 
@@ -49,7 +50,7 @@ typedef enum { /*< skip >*/
 } GthZoomQuality;
 
 
-typedef enum { /*< skip >*/
+typedef enum { 
 	GTH_FIT_NONE = 0,
 	GTH_FIT_SIZE,
 	GTH_FIT_SIZE_IF_LARGER,
@@ -63,6 +64,7 @@ typedef enum { /*< skip >*/
 	GTH_ZOOM_CHANGE_KEEP_PREV,
 	GTH_ZOOM_CHANGE_FIT_SIZE,
 	GTH_ZOOM_CHANGE_FIT_SIZE_IF_LARGER,
+	GTH_ZOOM_CHANGE_FIT_WIDTH,
 	GTH_ZOOM_CHANGE_FIT_WIDTH_IF_LARGER
 } GthZoomChange;
 
@@ -202,8 +204,10 @@ GtkWidget*     image_viewer_new                      (void);
 
 /* viewer content. */
 
-void           image_viewer_load_image               (ImageViewer     *viewer,
+void           image_viewer_load_image_from_uri      (ImageViewer     *viewer,
 						      const char      *path);
+void           image_viewer_load_image                (ImageViewer     *viewer,
+			 			      FileData        *file);						      
 void           image_viewer_load_from_pixbuf_loader  (ImageViewer     *viewer,
 						      GdkPixbufLoader *loader);
 void           image_viewer_load_from_image_loader   (ImageViewer     *viewer,
