@@ -45,6 +45,7 @@
 #define  PREF_MIGRATE_COMMENT_SYSTEM "/apps/gthumb/general/migrate_comment_system"
 
 #define  PREF_SHOW_HIDDEN_FILES      "/apps/gthumb/browser/show_hidden_files"
+#define  PREF_SHOW_ONLY_IMAGES       "/apps/gthumb/browser/show_only_images"
 #define  PREF_SHOW_FILENAMES         "/apps/gthumb/browser/show_filenames"
 #define  PREF_SHOW_COMMENTS          "/apps/gthumb/browser/show_comments"
 #define  PREF_SHOW_THUMBNAILS        "/apps/gthumb/browser/show_thumbnails"
@@ -71,8 +72,20 @@
 #define  PREF_SINGLE_WINDOW          "/apps/gthumb/viewer/single_window"
 
 #define  PREF_SLIDESHOW_DIR          "/apps/gthumb/slideshow/direction"
-#define  PREF_SLIDESHOW_DELAY        "/apps/gthumb/slideshow/delay"
+#define  PREF_SLIDESHOW_DELAY        "/apps/gthumb/slideshow/change_delay"
 #define  PREF_SLIDESHOW_WRAP_AROUND  "/apps/gthumb/slideshow/wrap_around"
+#define  PREF_SLIDESHOW_FADING       "/apps/gthumb/slideshow/fading"
+
+#define  PREF_HOTKEY0                "/apps/gthumb/hotkeys/hotkey0"
+#define  PREF_HOTKEY1                "/apps/gthumb/hotkeys/hotkey1"
+#define  PREF_HOTKEY2                "/apps/gthumb/hotkeys/hotkey2"
+#define  PREF_HOTKEY3                "/apps/gthumb/hotkeys/hotkey3"
+#define  PREF_HOTKEY4                "/apps/gthumb/hotkeys/hotkey4"
+#define  PREF_HOTKEY5                "/apps/gthumb/hotkeys/hotkey5"
+#define  PREF_HOTKEY6                "/apps/gthumb/hotkeys/hotkey6"
+#define  PREF_HOTKEY7                "/apps/gthumb/hotkeys/hotkey7"
+#define  PREF_HOTKEY8                "/apps/gthumb/hotkeys/hotkey8"
+#define  PREF_HOTKEY9                "/apps/gthumb/hotkeys/hotkey9"
 
 #define  PREF_UI_LAYOUT              "/apps/gthumb/ui/layout"
 #define  PREF_UI_TOOLBAR_STYLE       "/apps/gthumb/ui/toolbar_style"
@@ -83,6 +96,7 @@
 #define  PREF_UI_IMAGE_PANE_VISIBLE  "/apps/gthumb/ui/image_pane_visible"
 #define  PREF_UI_TOOLBAR_VISIBLE     "/apps/gthumb/ui/toolbar_visible"
 #define  PREF_UI_STATUSBAR_VISIBLE   "/apps/gthumb/ui/statusbar_visible"
+#define  PREF_UI_FILTERBAR_VISIBLE   "/apps/gthumb/ui/filterbar_visible"
 #define  PREF_UI_SIDEBAR_SIZE        "/apps/gthumb/ui/sidebar_size"
 #define  PREF_UI_SIDEBAR_CONTENT_SIZE "/apps/gthumb/ui/sidebar_content_size"
 #define  PREF_UI_COMMENT_PANE_SIZE   "/apps/gthumb/ui/comment_pane_size"
@@ -188,9 +202,16 @@
 #define  PREF_PRINT_MARGIN_BOTTOM     "/apps/gthumb/dialogs/print/margin_bottom"
 #define  PREF_PRINT_PAPER_UNIT        "/apps/gthumb/dialogs/print/paper_unit"
 #define  PREF_PRINT_IMAGES_PER_PAGE   "/apps/gthumb/dialogs/print/images_per_page"
+#define  PREF_PRINT_IMAGE_UNIT	      "/apps/gthumb/dialogs/print/image_unit"
+#define  PREF_PRINT_IMAGE_SIZING      "/apps/gthumb/dialogs/print/image_sizing"
+#define  PREF_PRINT_IMAGE_WIDTH	      "/apps/gthumb/dialogs/print/image_width"
+#define  PREF_PRINT_IMAGE_HEIGHT      "/apps/gthumb/dialogs/print/image_height"
+#define  PREF_PRINT_IMAGE_RESOLUTION  "/apps/gthumb/dialogs/print/image_resolution"
+
 
 #define  PREF_MSG_CANNOT_MOVE_TO_TRASH "/apps/gthumb/dialogs/messages/cannot_move_to_trash"
 #define  PREF_MSG_SAVE_MODIFIED_IMAGE  "/apps/gthumb/dialogs/messages/save_modified_image"
+#define  PREF_MSG_JPEG_MCU_WARNING     "/apps/gthumb/dialogs/messages/jpeg_mcu_warning"
 
 #define  PREF_CHOOSE_DESTINATION_VIEW  "/apps/gthumb/dialogs/choose_destination/view"
 
@@ -292,6 +313,12 @@ GthPreviewContent  pref_get_preview_content        (void);
 GthViewMode        pref_get_view_mode              (void);
 void               pref_set_print_unit             (GthPrintUnit value);
 GthPrintUnit       pref_get_print_unit             (void);
+void               pref_set_image_unit             (GthPrintUnit value);
+GthPrintUnit       pref_get_image_unit             (void);
+void               pref_set_image_sizing           (GthImageSizing value);
+GthImageSizing     pref_get_image_sizing           (void);
+void               pref_set_image_resolution       (GthImageResolution value);
+GthImageResolution pref_get_image_resolution       (void);
 void               pref_set_crop_ratio             (GthCropRatio value);
 GthCropRatio       pref_get_crop_ratio             (void);
 
