@@ -29,6 +29,7 @@
 #include <libgnomecanvas/libgnomecanvas.h>
 
 #include "glib-utils.h"
+#include "gtk-utils.h"
 #include "gth-utils.h"
 #include "gth-window.h"
 #include "gconf-utils.h"
@@ -459,7 +460,6 @@ dlg_crop (GthWindow *window)
 	char         *label;
 	GthCropRatio  crop_ratio;
 	int           ratio_w, ratio_h;
-	GdkScreen    *screen;
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
@@ -530,8 +530,8 @@ dlg_crop (GthWindow *window)
 	g_free (label);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (menu), item, 2);
 
-	data->screen_width = gdk_screen_get_width (gdk_screen_get_default ());
-	data->screen_height = gdk_screen_get_height (gdk_screen_get_default ());
+	get_screen_size (GTK_WINDOW (window), &data->screen_width, &data->screen_height);
+
 	label = g_strdup_printf (_("%d x %d (Screen)"), data->screen_width, data->screen_height);
 	item = gtk_menu_item_new_with_label (label);
 	gtk_widget_show (item);
@@ -662,10 +662,9 @@ dlg_crop (GthWindow *window)
 
 	gtk_widget_realize (data->dialog);
 
-	screen = gdk_screen_get_default();
 	gtk_window_set_default_size (GTK_WINDOW (data->dialog),
-				     gdk_screen_get_width (screen) * 7 / 10,
-				     gdk_screen_get_height (screen) * 6 / 10);
+				     data->screen_width * 7 / 10,
+				     data->screen_height * 6 / 10);
 
 	gth_iviewer_zoom_to_fit (GTH_IVIEWER (data->image_selector));
 	gtk_widget_grab_focus (data->image_selector);
