@@ -138,7 +138,7 @@ dlg_show_error (GthWindow  *window,
 		GList      *error_list,
 		const char *reason)
 {
-	const int   max_files = 15; /* FIXME */
+	const int   max_files = 15; /* FIXME: find a good value */
 	GtkWidget  *d;
 	GList      *scan;
 	char       *msg;
@@ -238,8 +238,8 @@ real_files_delete__continue (GnomeVFSResult result,
 					  cfddata->file_list,
 					  real_files_delete__continue2,
 					  cfddata);
-
-	} else
+	} 
+	else
 		real_files_delete__continue2 (result, data);
 }
 
@@ -550,7 +550,6 @@ set_filename_labels (GladeXML    *gui,
 }
 
 
-
 /* -- dlg_overwrite -- */
 
 
@@ -711,13 +710,13 @@ create_overwrite_dialog (GthWindow         *window,
 	gtk_container_add (GTK_CONTAINER (old_image_frame), old_image_viewer);
 
 	viewer = IMAGE_VIEWER (old_image_viewer);
-	image_viewer_size             (viewer, PREVIEW_SIZE, PREVIEW_SIZE);
+	image_viewer_size (viewer, PREVIEW_SIZE, PREVIEW_SIZE);
 	image_viewer_set_zoom_quality (viewer, pref_get_zoom_quality ());
-	image_viewer_set_check_type   (viewer, image_viewer_get_check_type (w_viewer));
-	image_viewer_set_check_size   (viewer, image_viewer_get_check_size (w_viewer));
-	image_viewer_set_transp_type  (viewer, image_viewer_get_transp_type (w_viewer));
-	image_viewer_set_fit_mode     (viewer, GTH_FIT_SIZE_IF_LARGER);
-	image_viewer_load_image       (viewer, old_filename);
+	image_viewer_set_check_type (viewer, image_viewer_get_check_type (w_viewer));
+	image_viewer_set_check_size (viewer, image_viewer_get_check_size (w_viewer));
+	image_viewer_set_transp_type (viewer, image_viewer_get_transp_type (w_viewer));
+	image_viewer_set_fit_mode (viewer, GTH_FIT_SIZE_IF_LARGER);
+	image_viewer_load_image_from_uri (viewer, old_filename);
 
 	gtk_widget_show (old_image_viewer);
 
@@ -727,13 +726,13 @@ create_overwrite_dialog (GthWindow         *window,
 	gtk_container_add (GTK_CONTAINER (new_image_frame), new_image_viewer);
 
 	viewer = IMAGE_VIEWER (new_image_viewer);
-	image_viewer_size             (viewer, PREVIEW_SIZE, PREVIEW_SIZE);
+	image_viewer_size (viewer, PREVIEW_SIZE, PREVIEW_SIZE);
 	image_viewer_set_zoom_quality (viewer, pref_get_zoom_quality ());
-	image_viewer_set_check_type   (viewer, image_viewer_get_check_type (w_viewer));
-	image_viewer_set_check_size   (viewer, image_viewer_get_check_size (w_viewer));
-	image_viewer_set_transp_type  (viewer, image_viewer_get_transp_type (w_viewer));
-	image_viewer_set_fit_mode     (viewer, GTH_FIT_SIZE_IF_LARGER);
-	image_viewer_load_image       (viewer, new_filename);
+	image_viewer_set_check_type (viewer, image_viewer_get_check_type (w_viewer));
+	image_viewer_set_check_size (viewer, image_viewer_get_check_size (w_viewer));
+	image_viewer_set_transp_type (viewer, image_viewer_get_transp_type (w_viewer));
+	image_viewer_set_fit_mode (viewer, GTH_FIT_SIZE_IF_LARGER);
+	image_viewer_load_image_from_uri (viewer, new_filename);
 
 	gtk_widget_show (new_image_viewer);
 
@@ -786,7 +785,7 @@ dlg_overwrite__response_cb (GtkWidget *dialog,
 				return;
 			}
 
-			new_path = g_build_path ("/", owdata->destination, new_name, NULL);
+			new_path = build_uri (owdata->destination, new_name, NULL);
 
 			if (path_is_file (new_path)) {
 				char *utf8_name;
@@ -887,7 +886,7 @@ dlg_overwrite_run (GthWindow     *window,
 			goto retry;
 		}
 
-		new_path = g_build_path ("/", owdata->destination, *new_name, NULL);
+		new_path = build_uri (owdata->destination, *new_name, NULL);
 
 		if (path_is_file (new_path)) {
 			char *utf8_name;
@@ -988,7 +987,7 @@ dlg_file_rename_series (GthWindow *window,
 				char *parent_dir;
 
 				parent_dir = remove_level_from_path (new_full_path);
-				new_full_path = g_build_path ("/", parent_dir,  new_name, NULL);
+				new_full_path = build_uri (parent_dir,  new_name, NULL);
 				g_free (parent_dir);
 				g_free (new_name);
 
@@ -1018,8 +1017,8 @@ dlg_file_rename_series (GthWindow *window,
 			files_created = my_list_remove (files_created, old_full_path);
 
 			o_scan = o_scan->next;
-
-		} else {
+		}
+		else {
 			old_names = g_list_remove_link (old_names, o_scan);
 			error_list = g_list_prepend (error_list, o_scan->data);
 			g_list_free (o_scan);
@@ -1057,7 +1056,6 @@ dlg_file_rename_series (GthWindow *window,
 }
 
 
-
 /* -- dlg_files_copy -- */
 
 typedef struct {
@@ -1251,10 +1249,9 @@ file_progress_update_cb (GnomeVFSAsyncHandle      *handle,
 				char *dest_file;
 
 				src_file = fcdata->current_file->data;
-				dest_file = g_build_path ("/",
-							  fcdata->destination,
-							  file_name_from_path (src_file),
-							  NULL);
+				dest_file = build_uri (fcdata->destination,
+						       file_name_from_path (src_file),
+						       NULL);
 				fcdata->copied_list = g_list_prepend (fcdata->copied_list, src_file);
 				fcdata->created_list = g_list_prepend (fcdata->created_list, dest_file);
 				copy_next_file (fcdata);
@@ -1290,6 +1287,10 @@ xfer_file (FileCopyData *fcdata,
 	xfer_error_mode = GNOME_VFS_XFER_ERROR_MODE_QUERY;
 	overwrite_mode  = GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE;
 
+	/* Delete thumbnail from cache, if source file is removed */
+	if (fcdata->remove_source)
+		delete_thumbnail (src_file);
+
 	result = gnome_vfs_async_xfer (&fcdata->handle,
 				       src_list,
 				       dest_list,
@@ -1339,10 +1340,9 @@ copy_current_file__overwrite (OverwriteResult  result,
 			break;
 		}
 
-		dest_file = g_build_path ("/",
-					  fcdata->destination,
-					  new_name,
-					  NULL);
+		dest_file = build_uri (fcdata->destination,
+				       new_name,
+				       NULL);
 		xfer_file (fcdata, src_file, dest_file);
 		g_free (dest_file);
 		g_free (new_name);
@@ -1350,10 +1350,9 @@ copy_current_file__overwrite (OverwriteResult  result,
 
 	case OVERWRITE_RESULT_YES:
 	case OVERWRITE_RESULT_ALL:
-		dest_file = g_build_path ("/",
-					  fcdata->destination,
-					  file_name_from_path (src_file),
-					  NULL);
+		dest_file = build_uri (fcdata->destination,
+				       file_name_from_path (src_file),
+				       NULL);
 		xfer_file (fcdata, src_file, dest_file);
 		g_free (dest_file);
 		break;
@@ -1394,10 +1393,9 @@ copy_current_file (FileCopyData *fcdata)
 	fcdata->result = GNOME_VFS_OK;
 
 	src_file = fcdata->current_file->data;
-	dest_file = g_build_path ("/",
-				  fcdata->destination,
-				  file_name_from_path (src_file),
-				  NULL);
+	dest_file = build_uri (fcdata->destination,
+			       file_name_from_path (src_file),
+			       NULL);
 
 	if (same_uri (src_file, dest_file)) {
 		g_free (dest_file);
@@ -1479,15 +1477,13 @@ copy_next_file (FileCopyData *fcdata)
 		char *src_cache_file;
 		char *dest_cache_file;
 
-		dest_file = g_strconcat (fcdata->destination,
-					 "/",
-					 file_name_from_path (src_file),
-					 NULL);
+		dest_file = add_filename_to_uri (fcdata->destination,
+						 file_name_from_path (src_file));
 
 		src_cache_file = comments_get_comment_filename (src_file, TRUE);
 		dest_cache_file = comments_get_comment_filename (dest_file, TRUE);
 
-		if (path_is_file (src_cache_file)) {
+		if (path_is_file (src_cache_file) && (dest_cache_file != NULL)) {
 			char *parent_dir;
 
 			parent_dir = remove_level_from_path (dest_cache_file);
@@ -1703,7 +1699,6 @@ dlg_files_move_to_trash (GthWindow      *window,
 }
 
 
-
 /* -- dlg_files_delete -- */
 
 
@@ -1909,7 +1904,12 @@ dlg_files_delete (GthWindow      *window,
 		GnomeVFSURI *uri;
 
 		uri = new_uri_from_path (path);
+
+		/* Prepare delete list */
 		src_list = g_list_prepend (src_list, uri);
+
+		/* delete associated thumbnails, if present */
+		delete_thumbnail (path);
 	}
 
 	if (src_list == NULL) {
@@ -1942,7 +1942,6 @@ dlg_files_delete (GthWindow      *window,
 }
 
 
-
 /* -- dlg_folder_copy -- */
 
 
@@ -2013,29 +2012,29 @@ folder_progress_update_cb (GnomeVFSAsyncHandle      *handle,
 	if (info->status != GNOME_VFS_XFER_PROGRESS_STATUS_OK) {
 		fcdata->result = info->vfs_status;
 		return FALSE;
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_INITIAL) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_INITIAL) {
 		/**/
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_COLLECTING) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_COLLECTING) {
 		message = g_strdup (_("Collecting images info"));
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_COPYING) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_COPYING) {
 		message = g_strdup_printf (_("Copying file %ld of %ld"),
 					   info->file_index,
 					   info->files_total);
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_MOVING) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_MOVING) {
 		message = g_strdup_printf (_("Moving file %ld of %ld"),
 					   info->file_index,
 					   info->files_total);
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_DELETESOURCE) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_DELETESOURCE) {
 		message = g_strdup_printf (_("Deleting file %ld of %ld"),
 					   info->file_index,
 					   info->files_total);
-
-	} else if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
+	} 
+	else if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED) {
 
 		if (fcdata->result == GNOME_VFS_OK) {
 			if (fcdata->file_op == FILE_OP_COPY)
