@@ -23,8 +23,8 @@
 #ifndef DLG_PNG_EXPORTER_H
 #define DLG_PNG_EXPORTER_H
 
-#include "gthumb-window.h"
+#include "gth-browser.h"
 
-void   dlg_exporter    (GThumbWindow *window);
+void   dlg_exporter    (GthBrowser *browser);
 
 #endif /* DLG_PNG_EXPORTER_H */
