@@ -44,6 +44,8 @@
 
 #include "config.h"
 
+#ifdef HAVE_GDKX
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -630,3 +632,5 @@ gs_fade_is_fading_out (GSFade *fade)
 {
 	return fade->priv->fading && (fade->priv->direction = GS_FADE_DIRECTION_OUT);
 }
+
+#endif /* HAVE_GDKX */
