@@ -68,12 +68,12 @@ gth_browser_activate_action_file_new_window (GtkAction  *action,
 	switch (gth_browser_get_sidebar_content (browser)) {
 	case GTH_SIDEBAR_DIR_LIST:
 		path = gth_browser_get_current_directory (browser);
-		uri = get_uri_from_path (path);
+		uri = add_scheme_if_absent (path);
 		break;
 
 	case GTH_SIDEBAR_CATALOG_LIST:
 		path = gth_browser_get_current_catalog (browser);
-		uri = g_strconcat ("catalog://", path, NULL);
+		uri = g_strconcat ("catalog://", remove_host_from_uri (path), NULL);
 		break;
 
 	default:
@@ -91,23 +91,24 @@ void
 gth_browser_activate_action_file_view_image (GtkAction  *action,
 					     GthBrowser *browser)
 {
-	const char *image_filename;
-	GtkWidget  *new_viewer;
+	FileData  *file;
+	GtkWidget *new_viewer;
 
-	image_filename = gth_window_get_image_filename (GTH_WINDOW (browser));
-	if (image_filename == NULL)
+	file = gth_window_get_image_data (GTH_WINDOW (browser));
+	if (file == NULL)
 		return;
 
 	if (eel_gconf_get_boolean (PREF_SINGLE_WINDOW, FALSE)) {
 		GtkWidget *viewer = gth_viewer_get_current_viewer ();
 		if (viewer != NULL) {
-			gth_viewer_load (GTH_VIEWER (viewer), image_filename);
+			gth_viewer_load (GTH_VIEWER (viewer), file);
 			gtk_window_present (GTK_WINDOW (viewer));
 			return;
 		}
 	}
 
-	new_viewer = gth_viewer_new (image_filename);
+	new_viewer = gth_viewer_new (NULL);
+	gth_viewer_load (GTH_VIEWER (new_viewer), file);
 	gtk_window_present (GTK_WINDOW (new_viewer));
 }
 
@@ -242,7 +243,7 @@ duplicate_file (GtkWindow  *window,
 					    try,
 					    (ext == NULL) ? "" : ext);
 
-		new_path = g_build_path ("/", dir, new_name, NULL);
+		new_path = build_uri (dir, new_name, NULL);
 		if (! path_is_file (new_path))
 			break;
 		g_free (new_name);
@@ -255,8 +256,8 @@ duplicate_file (GtkWindow  *window,
 	if (file_copy (old_path, new_path)) {
 		cache_copy (old_path, new_path);
 		comment_copy (old_path, new_path);
-
-	} else {
+	} 
+	else {
 		char      *utf8_path;
 		char      *msg;
 		GtkWidget *d;
@@ -506,11 +507,12 @@ catalog_rename (GthBrowser *browser,
 		_gtk_error_dialog_run (GTK_WINDOW (browser),
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
-
-	} else if (file_rename (catalog_path, new_catalog_path)) {
+	} 
+	else if (file_rename (catalog_path, new_catalog_path) == GNOME_VFS_OK) {
 		all_windows_notify_catalog_rename (catalog_path,
 						   new_catalog_path);
-	} else {
+	} 
+	else {
 		char *utf8_name;
 
 		utf8_name = gnome_vfs_unescape_string_for_display (name_only);
@@ -789,7 +791,7 @@ create_new_folder_or_library (GthBrowser *browser,
 
 	/* Create folder */
 
-	new_path = g_build_path ("/", current_path, new_name, NULL);
+	new_path = build_uri (current_path, new_name, NULL);
 
 	if (path_is_dir (new_path)) {
 		char *utf8_name;
@@ -798,8 +800,8 @@ create_new_folder_or_library (GthBrowser *browser,
 		_gtk_error_dialog_run (GTK_WINDOW (browser),
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
-
-	} else if (! dir_make (new_path, 0755)) {
+	} 
+	else if (! dir_make (new_path, 0755)) {
 		char *utf8_path;
 
 		utf8_path = gnome_vfs_unescape_string_for_display (new_path);
@@ -808,7 +810,8 @@ create_new_folder_or_library (GthBrowser *browser,
 				       utf8_path,
 				       errno_to_string ());
 		g_free (utf8_path);
-	} else
+	} 
+	else
 		all_windows_notify_directory_new (new_path);
 
 	g_free (new_path);
@@ -911,7 +914,7 @@ gth_browser_activate_action_edit_dir_view_new_window (GtkAction  *action,
 	if (path == NULL)
 		return;
 
-	uri = get_uri_from_path (path);
+	uri = add_scheme_if_absent (path);
 	gtk_widget_show (gth_browser_new (uri));
 
 	g_free (uri);
@@ -929,7 +932,7 @@ show_folder (GtkWindow  *window,
 	if (path == NULL)
 		return;
 
-	uri = get_uri_from_path (path);
+	uri = add_scheme_if_absent (path);
 	result = gnome_vfs_url_show (uri);
 	if (result != GNOME_VFS_OK)
 		_gtk_error_dialog_run (window, gnome_vfs_result_to_string (result));
@@ -998,7 +1001,7 @@ folder_rename (GtkWindow  *window,
 	/* Rename */
 
 	parent_path = remove_level_from_path (old_path);
-	new_path = g_build_path ("/", parent_path, new_name, NULL);
+	new_path = build_uri (parent_path, new_name, NULL);
 	g_free (parent_path);
 
 	all_windows_remove_monitor ();
@@ -1012,16 +1015,16 @@ folder_rename (GtkWindow  *window,
 				       utf8_path,
 				       _("source and destination are the same"));
 		g_free (utf8_path);
-
-	} else if (path_is_dir (new_path)) {
+	} 
+	else if (path_is_dir (new_path)) {
 		char *utf8_name;
 
 		utf8_name = gnome_vfs_unescape_string_for_display (new_name);
 		_gtk_error_dialog_run (window,
 				       _("The name \"%s\" is already used. " "Please use a different name."), utf8_name);
 		g_free (utf8_name);
-
-	} else {
+	} 
+	else {
 		char           *old_folder_comment;
 		GnomeVFSResult  result;
 
@@ -1038,8 +1041,8 @@ folder_rename (GtkWindow  *window,
 			g_free (new_folder_comment);
 
 			all_windows_notify_directory_rename (old_path, new_path);
-
-		} else {
+		} 
+		else {
 			char *utf8_path;
 			utf8_path = gnome_vfs_unescape_string_for_display (old_path);
 			_gtk_error_dialog_run (window,
@@ -1147,8 +1150,8 @@ folder_delete__continue (GnomeVFSResult result,
 					   fddata->path,
 					   folder_delete__continue2,
 					   fddata);
-
-	} else
+	} 
+	else
 		folder_delete__continue2 (result, data);
 }
 
@@ -1274,7 +1277,7 @@ folder_copy__response_cb (GObject *object,
 	gtk_widget_hide (file_sel);
 
 	dir_name = file_name_from_path (old_path);
-	new_path = g_build_path ("/", dest_dir, dir_name, NULL);
+	new_path = build_uri (dest_dir, dir_name, NULL);
 
 	if (gnome_vfs_check_same_fs (old_path, dest_dir, &same_fs) != GNOME_VFS_OK)
 		same_fs = FALSE;
@@ -1291,8 +1294,8 @@ folder_copy__response_cb (GObject *object,
 				       utf8_path,
 				       _("source and destination are the same"));
 		g_free (utf8_path);
-
-	} else if (path_in_path (old_path, new_path)) {
+	} 
+	else if (path_in_path (old_path, new_path)) {
 		char *utf8_path;
 
 		utf8_path = gnome_vfs_unescape_string_for_display (old_path);
@@ -1302,8 +1305,8 @@ folder_copy__response_cb (GObject *object,
 				       utf8_path,
 				       _("source contains destination"));
 		g_free (utf8_path);
-
-	} else if (path_is_dir (new_path)) {
+	} 
+	else if (path_is_dir (new_path)) {
 		char *utf8_name;
 
 		utf8_name = gnome_vfs_unescape_string_for_display (dir_name);
@@ -1313,8 +1316,8 @@ folder_copy__response_cb (GObject *object,
 				       utf8_name,
 				       _("a folder with that name is already present."));
 		g_free (utf8_name);
-
-	} else if (! (move && same_fs)) {
+	} 
+	else if (! (move && same_fs)) {
 		g_object_set_data_full (G_OBJECT (file_sel),
 					"new_path",
 					g_strdup (new_path),
@@ -1328,8 +1331,8 @@ folder_copy__response_cb (GObject *object,
 				 folder_copy__continue,
 				 file_sel);
 		file_sel = NULL;
-
-	} else {
+	} 
+	else {
 		char           *old_folder_comment = NULL;
 		GnomeVFSResult  result;
 
@@ -1352,8 +1355,8 @@ folder_copy__response_cb (GObject *object,
 
 			if (gth_folder_selection_get_goto_destination (GTH_FOLDER_SELECTION (file_sel)))
 				gth_browser_go_to_directory (GTH_BROWSER (window), new_path);
-
-		} else {
+		} 
+		else {
 			char *utf8_path;
 
 			utf8_path = gnome_vfs_unescape_string_for_display (old_path);
@@ -1734,11 +1737,10 @@ gth_browser_activate_action_go_location (GtkAction  *action,
 					       NULL);
 	/* Permit VFS URIs */
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), FALSE);
-
-	gtk_window_set_modal (GTK_WINDOW (chooser), TRUE);
 	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (chooser), gth_browser_get_current_directory (browser));
+	gtk_dialog_set_default_response(GTK_DIALOG (chooser), GTK_RESPONSE_OK);
 
-	g_signal_connect (G_OBJECT (GTK_DIALOG (chooser)),
+	g_signal_connect (G_OBJECT (chooser),
 			  "response",
 			  G_CALLBACK (open_location_response_cb),
 			  browser);
@@ -1777,7 +1779,7 @@ gth_browser_activate_action_bookmarks_add (GtkAction  *action,
 
 		if (dir_list->path == NULL)
 			return;
-		path = get_uri_from_path (dir_list->path);
+		path = add_scheme_if_absent (dir_list->path);
 	}
 
 	if (path == NULL)
@@ -1929,7 +1931,7 @@ gth_browser_activate_action_view_show_info (GtkAction  *action,
 
 void
 gth_browser_activate_action_view_show_hidden_files (GtkAction  *action,
-							GthBrowser *browser)
+						    GthBrowser *browser)
 {
 	eel_gconf_set_boolean (PREF_SHOW_HIDDEN_FILES, gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)));
 }
