@@ -50,7 +50,7 @@ static const gchar *main_ui_info =
 "      <menuitem action='File_CameraImport'/>"
 "      <menuitem action='File_WriteToCD'/>"
 "      <separator name='sep04'/>"
-"      <menuitem action='File_CloseWindow'/>"
+"      <menuitem name='Close' action='File_CloseWindow'/>"
 "    </menu>"
 "    <menu name='Edit' action='EditMenu'>"
 "      <menuitem action='Edit_Undo'/>"
@@ -74,7 +74,7 @@ static const gchar *main_ui_info =
 "      <menuitem action='Edit_AddToCatalog'/>"
 "      <menuitem action='Edit_RemoveFromCatalog'/>"
 "      <separator/>"
-"      <menuitem action='Tools_Preferences'/>"
+"      <menuitem name='Preferences' action='Tools_Preferences'/>"
 "    </menu>"
 "    <menu name='View' action='ViewMenu'>"
 "      <menu name='ShowHide' action='ViewShowHideMenu'>"
@@ -195,7 +195,7 @@ static const gchar *main_ui_info =
 "      <menuitem action='Help_Help'/>"
 "      <menuitem action='Help_Shortcuts'/>"
 "      <separator/>"
-"      <menuitem action='Help_About'/>"
+"      <menuitem name='About' action='Help_About'/>"
 "    </menu>"
 "  </menubar>"
 "  <toolbar name='ToolBar'>"
