@@ -301,7 +301,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
         GtkAction *action;
         char      *message;
 
-        action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
+        action = gtk_widget_get_action (GTK_WIDGET (proxy));
         g_return_if_fail (action != NULL);
 
         g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
